/* 
 * The Contents of this file are made available subject to the terms of 
 * the GNU Lesser General Public License Version 2.1
 *
 * GNU Lesser General Public License Version 2.1
 * =============================================
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1, as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 * 
 * Copyright (c) 2005 Cedric Bosdonnat
 *
 * All Rights Reserved.
 */
#include <com/sun/star/uno/Any.h>
#include <cppuhelper/weak.hxx>

#include <iostream>

#include "org/stareditor/exercise/Server.hpp"
#include "org/stareditor/comp/exercise/ClientImpl.hxx"

//===========================================================================
// This file only contains the Client implementation. like in any
// normal C++ program. This means that the cxx file is completely
// different from the hpp generated one.

using namespace std;
using namespace rtl;
using namespace org::stareditor::comp::exercise;
namespace css = com::sun::star;
namespace ose = org::stareditor::exercise;


//-------------------------------------------------------------------
// Service description methods for registration

/*
 * Static create method, see the implementation of the ExerciseImpl
 * class one for further details.
 */
css::uno::Reference<css::uno::XInterface> SAL_CALL ClientImpl::create (
          css::uno::Reference<css::uno::XComponentContext> const & xCtx)
{
    return static_cast<cppu::OWeakObject *>(new ClientImpl(xCtx));
} 

/*
 * Implementation of the getSupportedServiceNames() method
 */
css::uno::Sequence<OUString> ClientImpl::getSupportedServiceNames()
{
    css::uno::Sequence<rtl::OUString> names (1);
    names[0] = OUString (
            RTL_CONSTASCII_USTRINGPARAM("org.stareditor.exercise.Client"));
    return names;
}

/*
 * Implementation of the getImplementationName() method.
 */
OUString ClientImpl::getImplementationName()
{
    return OUString(
            RTL_CONSTASCII_USTRINGPARAM(
                "org.stareditor.comp.exercise.ClientImpl"));
}

//-------------------------------------------------------------------
// org::stareditor::exercise::XClient methods implementation

/*
 * Implementation of the getMore() method described in the UNO-IDL
 * specifications. In this implementation, the Client asks for 
 * money to the Server as long as the Server can give him.
 *
 * Note the throw with no exceptions. It is imposed by the UNO-IDL
 *    C++ linking. It has to be put for methods that do not throw
 *    anything.
 */
void ClientImpl::getMore() throw()
{
    // Checks if the server member is a reference to XServer
    if (__server.is())
    {
        sal_Int16 recieved;
                
        // Ask as much as possible ;)
        do
        {
            recieved = __server->give(100);
            if (recieved > 0) 
            {
                // Just print that he gets money !
                cout << "CLIENT: recieved " << recieved;
                cout << " from server" << endl;
            }
        } while (recieved > 0);
    }
}
    
//-------------------------------------------------------------------
// Constructor and destructor implementations

/*
 * ClientImpl constructor implementation. It uses the Component
 * Context to get the Server. If not, prints that something went
 * wrong.
 */
ClientImpl::ClientImpl(
        css::uno::Reference<css::uno::XComponentContext> const & xCtx)
{
    try
    {
        // Tries to get the Server instance. This method is
        // defined in the generated hpp file for the Server.
        __server = ose::Server::get(xCtx);
    }
    catch (css::uno::RuntimeException e)
    {
        // If something went wrong, then print an error message
        cerr << "Failed to get SERVER" << endl;
        cerr << "  -->" << OUStringToOString( 
                e.Message, RTL_TEXTENCODING_ASCII_US );
        cerr << endl;
    }
}

/*
 * ClientImpl destructor implementation. Don't forget to release the
 * Server interface reference.
 */
ClientImpl::~ClientImpl()
{
    // Unreferences the server
    __server.clear();
}

