/* 
 * The Contents of this file are made available subject to the terms of 
 * the GNU Lesser General Public License Version 2.1
 *
 * GNU Lesser General Public License Version 2.1
 * =============================================
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1, as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 * 
 * Copyright (c) 2005 Cedric Bosdonnat
 *
 * All Rights Reserved.
 */
#include <sal/config.h>
#include <com/sun/star/uno/Reference.h>
#include <com/sun/star/uno/Sequence.h>
#include <com/sun/star/uno/XComponentContext.hpp>
#include <cppuhelper/implbase1.hxx>
#include <cppuhelper/weak.hxx>
#include <rtl/ustring.hxx>

#include "org/stareditor/exercise/XClient.hpp"
#include "org/stareditor/exercise/XServer.hpp"

namespace css = com::sun::star;
namespace ose = org::stareditor::exercise;

namespace org { namespace stareditor { namespace comp { namespace exercise {

/*
 * See the ExerciseImpl class comment to undestand this inheritance
 */
class ClientImpl: public cppu::WeakImplHelper1<ose::XClient>
{
    public:
        
        /*
         * Constructor of the Client implementation. The Context will
         * be used to get the reference to the server.
         */
        explicit ClientImpl(
            css::uno::Reference<css::uno::XComponentContext> const & xCtx);
        
        /*
         * Destructor of the Client Implementation
         */
        ~ClientImpl(); 
        
        /*
         * Implementation of the getMore() method defined in the
         * UNO-IDL specification of the ose::XClient. Each method
         * of the implemented interface has to be implemented by 
         * the implementation class.
         */
        void getMore() throw();
            
        /*
         * Static creation method of the ClientImpl class used by the 
         * component registration methods
         */
        static css::uno::Reference<css::uno::XInterface> SAL_CALL create (
             css::uno::Reference<css::uno::XComponentContext> const & xCtx);

        /*
         * Method returning the supported service names for this 
         * implementation class.
         */
        static css::uno::Sequence<rtl::OUString> getSupportedServiceNames();

        /*
         * Method returning the name of the implementation. 
         * This is used by the registration methods.
         */
        static rtl::OUString getImplementationName();
        
    private:

        /*
         * Member to store the Server serving the client.
         */
        css::uno::Reference<ose::XServer> __server;

}; // end of ClientImpl
    
} // end of exercise   
} // end of comp
} // end of stareditor
} // end of org
