/* 
 * The Contents of this file are made available subject to the terms of 
 * the GNU Lesser General Public License Version 2.1
 *
 * GNU Lesser General Public License Version 2.1
 * =============================================
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1, as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 * 
 * Copyright (c) 2005 Cedric Bosdonnat
 *
 * All Rights Reserved.
 */
#include <cppuhelper/weak.hxx>
#include <iostream>

#include "org/stareditor/comp/exercise/ServerImpl.hxx"

//===========================================================================
// This file only contains the Client implementation. like in any
// normal C++ program. This means that the cxx file is completely
// different from the hpp generated one.

namespace css = com::sun::star;
namespace ose = org::stareditor::exercise;
using namespace org::stareditor::comp::exercise;
using namespace std;
using namespace rtl;


//-------------------------------------------------------------------
// Service description methods for registration


/*
 * Static create method, see the implementation of the ExerciseImpl
 * class one for further details.
 */
css::uno::Reference<css::uno::XInterface> SAL_CALL ServerImpl::create(
       css::uno::Reference<css::uno::XComponentContext> const & xCtx)
{
    return static_cast<cppu::OWeakObject *>(new ServerImpl(500));
}
   

/*
 * Implementation of the getSupportedServiceNames() method
 */
css::uno::Sequence<OUString> ServerImpl::getSupportedServiceNames() 
{
    css::uno::Sequence<OUString> names(1);
    names[0] = OUString(
           RTL_CONSTASCII_USTRINGPARAM("org.stareditor.exercise.Server"));
    return names;
}
            
/*
 * Implementation of the getImplementationName() method.
 */
OUString ServerImpl::getImplementationName()
{
    return OUString( 
           RTL_CONSTASCII_USTRINGPARAM(
               "org.stareditor.comp.exercise.ServerImpl"));
}
    
//-------------------------------------------------------------------
// org::stareditor::exercise::XServer methods implementation

/*
 * Implementation of the give() method defined in the UNO-IDL
 * specification. In this implementation, the server gives money
 * only to a maximum defined during the singleton construction.
 * Who has already seen a banker giving as money as you want ?
 */
sal_Int16 ServerImpl::give(sal_Int16 amount) throw()
{
    sal_Int16 result = 0;
    
    if ((__given + amount) <= __max)
    {
        // Just write down that he give some money
        cout << "SERVER: gives " << amount << endl;
        result = amount;
        __given += amount;
    }

    return result;
}

//-------------------------------------------------------------------
// Constructor and destructor implementations

/*
 * ServerImpl constructor implementation. It just initializes the
 * max to the given value, and the amount of given money at 0.
 */
ServerImpl::ServerImpl(sal_Int16 max):__max(max),__given(0)
{
}

/*
 * ServerImpl destructor implementation.
 */
ServerImpl::~ServerImpl()
{
}

