/* 
 * The Contents of this file are made available subject to the terms of 
 * the GNU Lesser General Public License Version 2.1
 *
 * GNU Lesser General Public License Version 2.1
 * =============================================
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1, as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 * 
 * Copyright (c) 2005 Cedric Bosdonnat
 *
 * All Rights Reserved.
 */
#include <sal/config.h>
#include <com/sun/star/uno/XComponentContext.hpp>
#include <com/sun/star/uno/Reference.h>
#include <com/sun/star/uno/Sequence.h>
#include <com/sun/star/uno/XInterface.hpp>
#include <cppuhelper/implbase1.hxx>
#include <rtl/ustring.hxx>

#include "org/stareditor/exercise/XServer.hpp"

namespace css = com::sun::star;
namespace ose = org::stareditor::exercise;

namespace org { namespace stareditor { namespace comp { namespace exercise {

/*
 * See the ExerciseImpl class comment to undestand this inheritance
 */
class ServerImpl: public cppu::WeakImplHelper1 <ose::XServer>
{

    public:

        sal_Int16 give (sal_Int16 amount) throw();

        /*
         * Static creation method of the ServerImpl class used by the 
         * component registration methods
         */
        static css::uno::Reference<css::uno::XInterface> SAL_CALL create(
            css::uno::Reference<css::uno::XComponentContext> const & xCtx);
            
        /*
         * Method returning the supported service names for this 
         * implementation class.
         */
        static css::uno::Sequence<rtl::OUString> getSupportedServiceNames();
      
        /*
         * Method returning the name of the implementation. 
         * This is used by the registration methods.
         */
        static rtl::OUString getImplementationName();
            
    private:

        /*
         * Constructor of the Server implementation. The only
         * parameter is the maximum amount that the server can
         * give to the client: it has nothing to do with the 
         * UNO-IDL specifications. In a singleton case, the 
         * constructor should be private, of course ;)
         */
        explicit ServerImpl(sal_Int16 max);
           
        /*
         * Destructor of the Server.
         */
        ~ServerImpl();
            
        /*
         * Members used for implementation only. They have nothing
         * to do with the specifications
         */
        sal_Int16 __max;
        sal_Int16 __given;
        
}; // end of ServerImpl

} } } } // end of all namespaces

